@@ -4,7 +4,4 @@ if not TYPE_CHECKING:
     import cesloi.event.messages
     import cesloi.event.test
     import cesloi.event.mirai
-    import cesloi.message.element
-    import cesloi.message
-    import cesloi.message.group
-    import cesloi.message.messageChain
+    import cesloi.event.lifecycle
